==> hexo-theme-solitude-1.8.12.tgz: package/README_ja.md <==
[简体中文](README.md)丨[繁体中文](README_zh-Hant.md)丨[English](README_en-US.md)丨[Français](README_fr.md)丨日本語

<div align="center">

   <img src=".github/logo.svg" alt="Solitude logo" height="200">

   <h1>ヘキソテーマソリチュード</h1>

遅延読み込み、PWA、ラテックス、および複数のコメントシステムをサポートするエレガントなHexoテーマ。

テーマは、 [@张洪Heo](https://github.com/zhheo) 著者の完全な権限、デザイン!

![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?logo=npm)
![release](https://img.shields.io/github/package-json/v/valor-x/hexo-theme-solitude/master?color=%231ab1ad&label=release)
![license](https://img.shields.io/github/license/valor-x/hexo-theme-solitude?color=FF5531)
[![Stars](https://img.shields.io/github/stars/valor-x/hexo-theme-solitude)](https://github.com/valor-x/hexo-theme-solitude/stargazers)
[![NPM all downloads](https://img.shields.io/npm/dy/hexo-theme-solitude?color=white)](https://www.npmjs.com/package/hexo-theme-solitude)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white)
![node version](https://img.shields.io/badge/node-14.0.0-white?logo=node.js&logoColor=white)

![Latex](https://img.shields.io/badge/latex-20B2AA?logo=Latex)
![Ads](https://img.shields.io/badge/Google_Ads-black?logo=googleads)
![algolia](https://img.shields.io/badge/algolia-457AFF?logo=algolia)

![cdnjs](https://img.shields.io/badge/cdnjs-orange?logo=Cloudflare&logoColor=white)
![A11y](https://img.shields.io/badge/A11y-green?logo=%C3%8Ele-de-France%20Mobilit%C3%A9s&logoColor=white)
![mermaid](https://img.shields.io/badge/mermaid-ff3670?logo=mermaid&logoColor=white)
[![pwa](https://img.shields.io/badge/pwa-red?logo=pwa)](https://developer.mozilla.org/en-US/docs/Web/Progressive_web_apps)

[![twiter](https://img.shields.io/badge/Twitter-gray?logo=x)](https://twitter.com/efu_oo)
[![TG](https://img.shields.io/badge/Telegram-gray?logo=Telegram&logoColor=white)](https://t.me/solitudePro)
[![Discord](https://img.shields.io/discord/1218118131428495430?label=Discord&logo=Discord&labelColor=white&color=black)](https://discord.gg/Y8VEvVgW)

![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains)
![DuoLingo](https://img.shields.io/badge/duolingo-support-black?logo=duolingo&logoColor=white)

[![gitee](https://img.shields.io/badge/Gitee-red?logo=gitee)](https://gitee.com/nsjjd_w/hexo-theme-solitude)
[![gitlab](https://img.shields.io/badge/GitLab-blue?logo=gitlab)](https://gitlab.com/efu/hexo-theme-solitude)

[プレビュー](https://www.efu.me/) 丨  [ドキュメンテーション](https://solitude-docs.efu.me/)

</div>

![Screenshot](.github/screenshot.png)

## 特性

- ページ遅延読み込み(Pjax)、画像遅延読み込み(LazyLoad)、オフラインアプリケーション(PWA)
- コメント(Twikoo、Waline、Valine、Artalk)
- カラーモード
- ライトボックス(中ズーム、ファンシーボックス)
- 数式(ラテックス)
- 注目のページ:インスタントエッセイ、マイ機器、オンラインツール、ミュージックギャラリー、フレンドチェーンフィッシュポンド、フォトアルバムページ、Doubanページ
- 記事の特徴:AIの要約、コードの強調表示

## すべての

- [x] Artalkレビュー
- [x] ダブルレビュー
- [x] 写真集

> ご不明な点がございましたら、お問い合わせください [issue](https://github.com/valor-x/hexo-theme-solitude/issues)

## 申し込む

1. インストールに NPM パッケージを使用する
      ```bash
      npm i hexo-theme-solitude
      ```
2. テーマを適用する
      ```yaml
      theme: solitude
      ```

詳しくは [Docs](https://solitude-docs.efu.me) をご覧ください。

## スポンサー

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg'/>
  </a>
</p>

## 著作権

[MIT](./LICENSE) License &copy; 2023-これまで [Efu](https://github.com/efuo)

==> hexo-theme-solitude-1.9.0.tgz: package/README_ja.md <==
[简体中文](README.md)丨[繁体中文](README_zh-Hant.md)丨[English](README_en-US.md)丨[Français](README_fr.md)丨日本語

<div align="center">

   <img src=".github/logo.svg" alt="Solitude logo" height="200">

   <h1>ヘキソテーマソリチュード</h1>

遅延読み込み、PWA、ラテックス、および複数のコメントシステムをサポートするエレガントなHexoテーマ。

テーマは、 [@张洪Heo](https://github.com/zhheo) 著者の完全な権限、デザイン!

![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?logo=npm)
![release](https://img.shields.io/github/package-json/v/valor-x/hexo-theme-solitude/master?color=%231ab1ad&label=release)
![license](https://img.shields.io/github/license/valor-x/hexo-theme-solitude?color=FF5531)
[![Stars](https://img.shields.io/github/stars/valor-x/hexo-theme-solitude)](https://github.com/valor-x/hexo-theme-solitude/stargazers)
[![NPM all downloads](https://img.shields.io/npm/dy/hexo-theme-solitude?color=white)](https://www.npmjs.com/package/hexo-theme-solitude)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white)
![node version](https://img.shields.io/badge/node-14.0.0-white?logo=node.js&logoColor=white)

![Latex](https://img.shields.io/badge/latex-20B2AA?logo=Latex)
![Ads](https://img.shields.io/badge/Google_Ads-black?logo=googleads)
![algolia](https://img.shields.io/badge/algolia-457AFF?logo=algolia)

![cdnjs](https://img.shields.io/badge/cdnjs-orange?logo=Cloudflare&logoColor=white)
![A11y](https://img.shields.io/badge/A11y-green?logo=%C3%8Ele-de-France%20Mobilit%C3%A9s&logoColor=white)
![mermaid](https://img.shields.io/badge/mermaid-ff3670?logo=mermaid&logoColor=white)
[![pwa](https://img.shields.io/badge/pwa-red?logo=pwa)](https://developer.mozilla.org/en-US/docs/Web/Progressive_web_apps)

[![twiter](https://img.shields.io/badge/Twitter-gray?logo=x)](https://twitter.com/efu_oo)
[![TG](https://img.shields.io/badge/Telegram-gray?logo=Telegram&logoColor=white)](https://t.me/solitudePro)
[![Discord](https://img.shields.io/discord/1218118131428495430?label=Discord&logo=Discord&labelColor=white&color=black)](https://discord.gg/Y8VEvVgW)

![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains)
![DuoLingo](https://img.shields.io/badge/duolingo-support-black?logo=duolingo&logoColor=white)

[![gitee](https://img.shields.io/badge/Gitee-red?logo=gitee)](https://gitee.com/nsjjd_w/hexo-theme-solitude)
[![gitlab](https://img.shields.io/badge/GitLab-blue?logo=gitlab)](https://gitlab.com/efu/hexo-theme-solitude)

[プレビュー](https://www.efu.me/) 丨  [ドキュメンテーション](https://docs.efu.me/)

</div>

![Screenshot](.github/screenshot.png)

## 特性

- ページ遅延読み込み(Pjax)、画像遅延読み込み(LazyLoad)、オフラインアプリケーション(PWA)
- コメント(Twikoo、Waline、Valine、Artalk)
- カラーモード
- ライトボックス(中ズーム、ファンシーボックス)
- 数式(ラテックス)
- 注目のページ:インスタントエッセイ、マイ機器、オンラインツール、ミュージックギャラリー、フレンドチェーンフィッシュポンド、フォトアルバムページ、Doubanページ
- 記事の特徴:AIの要約、コードの強調表示

## すべての

- [x] Artalkレビュー
- [x] ダブルレビュー
- [x] 写真集

> ご不明な点がございましたら、お問い合わせください [issue](https://github.com/valor-x/hexo-theme-solitude/issues)

## 申し込む

1. インストールに NPM パッケージを使用する
      ```bash
      npm i hexo-theme-solitude
      ```
2. テーマを適用する
      ```yaml
      theme: solitude
      ```

詳しくは [Docs](https://docs.efu.me) をご覧ください。

## スポンサー

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg'/>
  </a>
</p>

## 著作権

[MIT](./LICENSE) License &copy; 2023-これまで [Efu](https://github.com/efuo)
